@@ -3,6 +3,7 @@ package Bio::SSRTool;
 use 5.006;
 use strict;
 use warnings;
+use autodie;
 use vars qw( @ISA @EXPORT @EXPORT_OK );
 use Carp qw( croak );
 use IO::Scalar;
@@ -21,7 +22,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -84,7 +85,7 @@ A positive integer between 1 and 10.  Default is 4.
     if ( ref $seq ne 'GLOB' ) {
         if ( $seq !~ /\n$/ && -e $seq ) {
             my $tmp = $seq;
-            open my $fh, '<', $tmp or croak "Can't read file '$tmp'\n";
+            open my $fh, '<', $tmp;
             $seq = $fh;
         }
         else {
